import { h } from 'preact'
import { useEffect, useRef, useState } from 'preact/hooks'
import { bool, func, string } from 'prop-types'
import 'regenerator-runtime/runtime'
import { PeerTubePlayer } from '@peertube/embed-api'

import Logo from '../Logo'
import Chat from '../Chat'
import { H2 } from '../Text'
import Overlay from '../VideoOverlay'
import { VideoWrapper, Iframe } from './styles'

const Video = ({ playing, setPlaying, src, title, org }) => {
  const videoiFrame = useRef(null)
  const overlayTimeout = useRef(null)
  const [videoReady, setVideoReady] = useState(false)
  const [overlayActive, setOverlayActiveState] = useState(true)
  const ptVideo = useRef(null)

  useEffect(() => {
    const setVideo = async () => {
      const player = new PeerTubePlayer(videoiFrame.current)
      await player.ready

      ptVideo.current = player
      player.setVolume(100)
      setVideoReady(true)
    }
    setVideo()
  }, [])

  useEffect(() => {
    const { current: player } = ptVideo

    if (!videoReady) return

    if (playing) {
      setOverlayActiveState(false)
      player.play()
    } else {
      setOverlayActiveState(true)
      player.pause()
    }
  }, [playing])

  const activateOverlay = () => {
    clearTimeout(overlayTimeout.current)
    setOverlayActiveState(true)

    overlayTimeout.current = setTimeout(
      () => setOverlayActiveState(false),
      2000
    )
  }

  return (
    <VideoWrapper
      $active={overlayActive || !playing}
      onClick={() => setPlaying(!playing)}
      onMouseMove={activateOverlay}
    >
      <Overlay active={overlayActive || !playing} title={title} org={org} />
      <Iframe
        sandbox="allow-same-origin allow-scripts allow-popups"
        src={`${src}?api=1&controls=false`}
        frameborder="0"
        allowfullscreen
        ref={videoiFrame}
      />
      <Chat />
    </VideoWrapper>
  )
}

Video.propTypes = {
  playing: bool,
  setPlaying: func.isRequired,
  src: string.isRequired,
  title: string.isRequired,
  org: string,
}

export default Video
